@@ -2,7 +2,7 @@
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2009-2011 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2019 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2021 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -327,7 +327,7 @@ void remmina_message_panel_setup_auth(RemminaMessagePanel *mp, RemminaMessagePan
 
 
 	if (flags & REMMINA_MESSAGE_PANEL_FLAG_USERNAME) {
-		widget = gtk_label_new(_("User name"));
+		widget = gtk_label_new(_("Username"));
 		gtk_widget_set_halign(GTK_WIDGET(widget), GTK_ALIGN_START);
 		gtk_widget_set_valign(GTK_WIDGET(widget), GTK_ALIGN_CENTER);
 		gtk_widget_set_margin_top (GTK_WIDGET(widget), 9);
@@ -349,6 +349,10 @@ void remmina_message_panel_setup_auth(RemminaMessagePanel *mp, RemminaMessagePan
 		gtk_grid_attach(GTK_GRID(grid), username_entry, 1, grid_row, 2, 1);
 		gtk_entry_set_max_length(GTK_ENTRY(username_entry), 100);
 
+		if (flags & REMMINA_MESSAGE_PANEL_FLAG_USERNAME_READONLY) {
+			g_object_set(username_entry, "editable", FALSE, NULL);
+		}
+
 		/*
 		if (default_username && default_username[0] != '\0') {
 			gtk_entry_set_text(GTK_ENTRY(username_entry), default_username);
@@ -400,6 +404,7 @@ void remmina_message_panel_setup_auth(RemminaMessagePanel *mp, RemminaMessagePan
 		gtk_widget_set_margin_bottom (GTK_WIDGET(domain_entry), 3);
 		gtk_widget_set_margin_start (GTK_WIDGET(domain_entry), 6);
 		gtk_widget_set_margin_end (GTK_WIDGET(domain_entry), 18);
+                gtk_entry_set_activates_default (GTK_ENTRY(domain_entry), TRUE);
 		gtk_widget_show(domain_entry);
 		gtk_grid_attach(GTK_GRID(grid), domain_entry, 1, grid_row, 2, 1);
 		gtk_entry_set_max_length(GTK_ENTRY(domain_entry), 100);
@@ -447,7 +452,6 @@ void remmina_message_panel_setup_auth(RemminaMessagePanel *mp, RemminaMessagePan
 	button_ok = gtk_button_new_with_label(_("_OK"));
 	gtk_button_set_use_underline(GTK_BUTTON(button_ok), TRUE);
 	gtk_widget_set_can_default(button_ok, TRUE);
-	gtk_widget_grab_default (button_ok);
 	gtk_container_add (GTK_CONTAINER (bbox), button_ok);
 	/* Buttons, ok and cancel */
 	button_cancel = gtk_button_new_with_label(_("_Cancel"));
@@ -461,6 +465,7 @@ void remmina_message_panel_setup_auth(RemminaMessagePanel *mp, RemminaMessagePan
 	priv->w[REMMINA_MESSAGE_PANEL_PASSWORD] = password_entry;
 	priv->w[REMMINA_MESSAGE_PANEL_FLAG_SAVEPASSWORD] = save_password_switch;
 	priv->w[REMMINA_MESSAGE_PANEL_DOMAIN] = domain_entry;
+	priv->w[REMMINA_MESSAGE_PANEL_BUTTONTOFOCUS] = button_ok;
 
 	priv->response_callback = response_callback;
 	priv->response_callback_data = response_callback_data;
@@ -615,7 +620,7 @@ void remmina_message_panel_setup_auth_x509(RemminaMessagePanel *mp, RemminaMessa
 	gtk_widget_set_margin_end (GTK_WIDGET(bbox), 18);
 	button_ok = gtk_button_new_with_label(_("_OK"));
 	gtk_widget_set_can_default (button_ok, TRUE);
-	gtk_widget_grab_default (button_ok);
+
 	gtk_button_set_use_underline(GTK_BUTTON(button_ok), TRUE);
 	//gtk_widget_show(button_ok);
 	gtk_container_add (GTK_CONTAINER (bbox), button_ok);
@@ -636,6 +641,7 @@ void remmina_message_panel_setup_auth_x509(RemminaMessagePanel *mp, RemminaMessa
 	priv->w[REMMINA_MESSAGE_PANEL_CACRLFILE] = cacrl_file;
 	priv->w[REMMINA_MESSAGE_PANEL_CLIENTCERTFILE] = clientcert_file;
 	priv->w[REMMINA_MESSAGE_PANEL_CLIENTKEYFILE] = clientkey_file;
+	priv->w[REMMINA_MESSAGE_PANEL_BUTTONTOFOCUS] = button_ok;
 
 	g_object_set_data(G_OBJECT(button_cancel), btn_response_key, (void *)GTK_RESPONSE_CANCEL);
 	g_signal_connect(G_OBJECT(button_cancel), "clicked", G_CALLBACK(remmina_message_panel_button_clicked_callback), mp);
@@ -656,6 +662,11 @@ void remmina_message_panel_focus_auth_entry(RemminaMessagePanel *mp)
 		return;
 	priv = remmina_message_panel_get_instance_private(mp);
 
+	/* Activate default button */
+	w = priv->w[REMMINA_MESSAGE_PANEL_BUTTONTOFOCUS];
+	if (w && G_TYPE_CHECK_INSTANCE_TYPE(w, gtk_button_get_type()))
+		gtk_widget_grab_default(w);
+
 	w = priv->w[REMMINA_MESSAGE_PANEL_USERNAME];
 	if (w == NULL)
 	{
@@ -687,7 +698,7 @@ void remmina_message_panel_field_set_string(RemminaMessagePanel *mp, int entryid
 	if (!G_TYPE_CHECK_INSTANCE_TYPE(priv->w[entryid], gtk_entry_get_type()))
 		return;
 
-	gtk_entry_set_text(GTK_ENTRY(priv->w[entryid]), text);
+	gtk_entry_set_text(GTK_ENTRY(priv->w[entryid]), text != NULL ? text : "");
 }
 
 gchar* remmina_message_panel_field_get_string(RemminaMessagePanel *mp, int entryid)
